# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/dreamai_pdf',
                'doc_host': 'https://HamzaFarhan.github.io',
                'git_url': 'https://github.com/HamzaFarhan/dreamai_pdf',
                'lib_path': 'dreamai_pdf'},
  'syms': { 'dreamai_pdf.core': { 'dreamai_pdf.core.cid_to_char': ('core.html#cid_to_char', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.extract_text': ('core.html#extract_text', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.process_text': ('core.html#process_text', 'dreamai_pdf/core.py')},
            'dreamai_pdf.imports': {},
            'dreamai_pdf.segment': { 'dreamai_pdf.segment.load_ems_model': ('segment.html#load_ems_model', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.load_segs_model': ('segment.html#load_segs_model', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.print_segments': ('segment.html#print_segments', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.text_to_segments': ('segment.html#text_to_segments', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.write_segments': ('segment.html#write_segments', 'dreamai_pdf/segment.py')}}}
